* version 1.3
  - Pack the scripts for PyPi.

* version 1.2
  - Switch scripts to Python 3.
  - Fix the database according to the latest DAC patches.

* version 1.1
  - Add new pieces and species according to the 29.03.2019 patch.
  - Fix combos and strategies.
  - Remove deactivated pieces: Riki, SandKing, Slark.

* version 1.0
  - Add new pieces and species according to the 26.02.2019 patch.

* version 0.9
  - Highlight the duplicated items in the item receipt by the yellow color.
  - Rework widgets geometry in the items-picker.py script.

* version 0.8
  - Add the combo-picker.py script.
  - Rework the widgets geometry in the pieces-picker.py script.

* version 0.7
  - Make a separate document for strategies.
  - Update the database according to the latest game changes.

* version 0.6
  - Add the description of the pieces skills.

* version 0.5
  - Add the combos-poicker.py script.

* version 0.4
  - Add stars to indicate the cost of pieces and tier of items.
  - Make the color scheme lighter.

* version 0.3
  - Add the items-picker.py script.

* version 0.2
  - Fix bugs with classes and species description.

* version 0.1
  - Implement basic features of the picker.
